@@ -1,9 +1,11 @@
-from typing import Optional
-import click
 from pathlib import Path
+from typing import Optional
+
+import click
+
 from palm.plugins.core.create_files import *
 
-palm_target_dir = f'{Path.cwd()}/.palm'
+palm_target_dir = f"{Path.cwd()}/.palm"
 templates_dir = Path(Path(__file__).parents[1], "templates").resolve()
 
 
@@ -19,9 +21,9 @@ templates_dir = Path(Path(__file__).parents[1], "templates").resolve()
 @click.option(
     "-c", "--commands", multiple=True, help="List of command names to scaffold"
 )
-@click.pass_context
+@click.pass_obj
 def cli(
-    ctx,
+    environment,
     image_name: Optional[str],
     plugins: Optional[tuple],
     protected_branches: Optional[tuple],
@@ -35,22 +37,22 @@ def cli(
     based on the options provided
     Creates command files based on the --commands option
     """
-    template_dir = Path(Path(__file__).parents[1], "templates") / 'command'
+    template_dir = Path(Path(__file__).parents[1], "templates") / "command"
 
     if Path(palm_target_dir).exists():
         click.secho("Palm is already initialized", fg="red")
         return
 
-    Path('.palm').mkdir()
-    Path('.palm/__init__.py').touch()
+    Path(".palm").mkdir()
+    Path(".palm/__init__.py").touch()
 
     for command in commands:
-        click.echo(f'Adding template for {command}...')
-        create_command(ctx, command, template_dir, palm_target_dir)
+        click.echo(f"Adding template for {command}...")
+        create_command(environment, command, template_dir, palm_target_dir)
 
     if not image_name:
-        image_name = ctx.obj.palm.image_name
+        image_name = environment.palm.image_name
 
     create_config(palm_target_dir, image_name, plugins, protected_branches)
 
-    click.secho('Success! Project initialized with Palm CLI', fg='green')
+    click.secho("Success! Project initialized with Palm CLI", fg="green")
